#[non_exhaustive]pub enum ImportDescriptorError {
CapabilityPackageMismatch {
slot_id: BoxId,
capability: CapabilityId,
},
DuplicateCapability {
capability: CapabilityId,
},
}Expand description
A failure to construct an import descriptor.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CapabilityPackageMismatch
An imported capability belonged to a package other than its slot.
Fields

capability: CapabilityIdThe mismatched qualified capability identity.
DuplicateCapability
A capability identity appeared more than once in the import set.
Fields

capability: CapabilityIdThe repeated capability identity.