pub struct ConformanceError { /* private fields */ }Expand description
A conformance failure with its descriptor path and payload-free category.
Implementations
Sourceimpl ConformanceError
impl ConformanceError
Sourcepub fn kind(&self) -> &ConformanceErrorKind
pub fn kind(&self) -> &ConformanceErrorKind
Returns the failure category.
Sourcepub fn path(&self) -> &[PathSegment]
pub fn path(&self) -> &[PathSegment]
Returns the path from the call slot to the failure.